@@ -199,7 +199,7 @@ void fill_user_stations_list(GSList * source_list, GtkListStore ** list) {
                 station_source = g_strdup("weather.com");
             }
 
-	    fprintf(stderr,"%s : %s : %s \n", station_code, station_name, station_source );
+           fprintf(stderr,"%s : %s : %s \n", station_code, station_name, station_source );
 #ifdef ENABLE_GPS
             /* gps or manual station */
             temp4 = strtok(NULL, "@");
@@ -425,24 +425,30 @@ gint read_config(AppletConfig * config) {
                                                          GCONF_KEY_WEATHER_CURRENT_STATION_ID,
                                                          NULL);
     if (config->current_station_id
-        && strlen(config->current_station_id) == 0)
+        && strlen(config->current_station_id) == 0){
+        g_free(config->current_station_id);
         config->current_station_id = NULL;
+    }
     /* Get Weather current station name. */
     config->current_station_name = NULL;
     config->current_station_name = gconf_client_get_string(gconf_client,
                                                            GCONF_KEY_WEATHER_CURRENT_STATION_NAME,
                                                            NULL);
     if (config->current_station_name
-        && strlen(config->current_station_name) == 0)
+        && strlen(config->current_station_name) == 0){
+        g_free(config->current_station_name);
         config->current_station_name = NULL;
+    }
     /* Get weather current station source */
     config->current_station_source = NULL;
     config->current_station_source = gconf_client_get_string(gconf_client,
                                                   GCONF_KEY_CURRENT_STATION_SOURCE,
                                                   NULL);
     if (config->current_station_source
-        && strlen(config->current_station_source) == 0)
+        && strlen(config->current_station_source) == 0){
+        g_free(config->current_station_source);
         config->current_station_source = NULL;
+    }
     /* Get GPS station name and id */
 #ifdef ENABLE_GPS
     app->gps_station.name[0] = 0;
@@ -527,10 +533,10 @@ gint read_config(AppletConfig * config) {
         add_gps_event(1);
     } else
         config->gps_station = FALSE;
-//#ifdef OS2009
+#if defined OS2009
         config->gps_station = TRUE;
         add_gps_event(1);
-//#endif
+#endif
 #endif
 
     /* Get Weather font color. */
